//
//  MyCalendar.m
//  CalendarTest1
//
//  Created by Otsu Makoto on 11/12/12.
//  Copyright (c) 2011年 __MyCompanyName__. All rights reserved.
//

#import "MyCalendar.h"

@implementation MyCalendar
{
    NSCalendar *_gCal;
}


- (id)init
{
    self = [super init];
    if (self) {
        // 暦をグレゴリオ暦に
        _gCal = [[NSCalendar alloc]
                initWithCalendarIdentifier:NSGregorianCalendar];	        
        // 現在の日付時刻を生成
        NSDate *today = [NSDate date];
        // 今日の年と月を設定
        NSUInteger unitFlags =  NSYearCalendarUnit | NSMonthCalendarUnit;
        NSDateComponents *comps = [_gCal components:unitFlags fromDate:today];
        self.year = [comps year];
        self.month = [comps month];
    }
    return self;
}

//　月の最初の日の曜日を求める
- (NSInteger)weekDayOfFirstDay
{
    NSDateComponents *comps = [[NSDateComponents alloc] init];
    // NSDateComponentsを指定した年、月の1日に
    [comps setDay:1];
    [comps setMonth:self.month];
    [comps setYear:self.year];
    NSDate *theDay = [_gCal dateFromComponents:comps];
    NSDateComponents *weekdayComps = [_gCal components:NSWeekdayCalendarUnit
                                            fromDate:theDay];
    return [weekdayComps weekday];
}	

// 指定した月の日数を求める
- (NSInteger)daysOfMonth:(NSInteger)m inYear:(NSInteger)y
{
    NSDateComponents *dayComp = [[NSDateComponents alloc] init];
    [dayComp setYear:y];
    [dayComp setMonth:m];
    [dayComp setDay:1];	
    NSDate *theDay = [_gCal dateFromComponents:dayComp];
    NSRange rangeDays = [_gCal rangeOfUnit:NSDayCalendarUnit
                                   inUnit:NSMonthCalendarUnit 
                                  forDate:theDay]; 
    return rangeDays.length;
}

// カレンダーを文字列にして戻す
- (NSString *)calendarString
{
    int column = 1;
    NSMutableString *calStr;
    calStr = [NSMutableString stringWithCapacity: 100];
    [calStr appendString:@" Su Mo Tu We Th Fr Sa\n"];
    
    // 最初の曜日までスキップ
    for (int i = 1; i < [self weekDayOfFirstDay]; i++) {
        [calStr appendString:@"   "];
        column ++;
    }
	
    NSString *day;
    for (int i = 1; i <= [self daysOfMonth:self.month inYear:self.year]; i++) {
        if (i < 10) {
            // 日付が1桁の場合はスペースを2つ
            day = [NSString stringWithFormat:@"  %d", i];
        } else {
            // 日付が2桁の場合はスペースを1つ
            day = [NSString stringWithFormat:@" %d", i];
        }
        [calStr appendString:day];
        // 1週間分表示したら改行を入れる
        if (column == 7) {
            [calStr appendString:@"\n"];
            column = 0;
        }
        column ++;
    }
    return calStr;
}

@end
